<template>
  <el-dialog
    width="60%"
    title="工艺文件"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <div v-show="showParentInfo">
      <el-row>
        <el-col :span="3"><span>印字方式：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].printType : "" }}</span></el-col
        >
        <el-col :span="3"><span>印字要求：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].printingRequirements : "" }}</span></el-col
        >
        <el-col :span="3"><span>盘长要求：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].lengthRequirement : "" }}</span></el-col
        >
        <el-col :span="3"><span>包装要求：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].packageRequire : "" }}</span></el-col
        >
      </el-row>
      <el-row>
        <el-col :span="3"><span>质量要求：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].qualityRequire : "" }}</span></el-col
        >
        <el-col :span="3"><span>生产需求说明：</span></el-col>
        <el-col :span="3"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].otherProductRequire : "" }}</span></el-col
        >
        <el-col :span="3"><span>备注：</span></el-col>
        <el-col :span="9"
          ><span>{{ relationOrderList[0] ? relationOrderList[0].remark : "" }}</span></el-col
        >
      </el-row>
    </div>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      :bottomOffset="350"
      :fixedHeight="tableFixHeight"
      ref="documentTable"
      :paramObj="queryParam"
    >
      <template #toolbar></template>
    </ttable>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
    <DocumentDetail :currshowlist.sync="showDocument" :docId="documentId">
    </DocumentDetail>
  </el-dialog>
</template>
<script>
import { fetchList } from '@/api/technology/document'
import ttable from '@/views/common/ztt-table.vue'
import DocumentDetail from '@/views/common/documentDetail.vue'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: true
    },
    showParentInfo: {
      type: Boolean,
      default: false
    },
    relationOrderList: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      ids: [],
      currentRow: null,
      ajaxFun: fetchList,
      innerVisible: false,
      multipleSelection: [],
      isShowQuery: false,
      showDocument: false,
      prelang: 'commonDocument',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮H
        isSearch: false, // 高级查询按钮
        cancelRunCreated: true,
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        column: [
          {
            minWidth: '140',
            prop: 'name',
            label: '文件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.openDetail }
          },
          {
            minWidth: '120',
            prop: 'number',
            label: '文件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            noShowTip: false
          },
          {
            minWidth: '120',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 绝缘颜色
          {
            minWidth: '120',
            prop: 'insulationColor',
            label: '绝缘颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 护套颜色
          {
            minWidth: '120',
            prop: 'sheathColor',
            label: '护套颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'version',
            label: '版本号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            noShowTip: false
          },
          {
            minWidth: '120',
            prop: 'projectNo',
            label: '项目号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'country',
            label: '国家',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'state',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getStateOptionList()
            },
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue == '01draft') {
                formatVal = '草稿'
              } else if (cellValue == '02pending') {
                formatVal = '待审批'
              } else if (cellValue == '03accepted') {
                formatVal = '已审批'
              } else {
                formatVal = '已驳回'
              }
              return formatVal
            }
          },
          // 描述
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 更新时间
          {
            minWidth: '200',
            prop: 'updateTime',
            label: '更新时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 创建时间
          {
            minWidth: '200',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [],
        operator: null,
        operatorConfig: {}
      },
      addOrUpdateVisible: false,
      masterOptionList: [
        {
          value: true,
          label: '是'
        },
        {
          value: false,
          label: '否'
        }
      ],
      stateOptionList: [
        {
          value: '01draft',
          label: '草稿'
        },
        {
          value: '02pending',
          label: '待审批'
        },
        {
          value: '03accepted',
          label: '已审批'
        },
        {
          value: '04reject',
          label: '已驳回'
        }
      ],
      documentId: null,
      queryParam: {
        state: '03accepted' // 增加只能选已审批的限制
      },
      tableFixHeight: 400
    }
  },
  components: {
    ttable,
    DocumentDetail
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          const rules = []
          let rule
          this.relationOrderList.forEach((item) => {
            if (item.partNo != null && item.partNo != '') {
              rule = {
                name: 'partNo',
                value: item.partNo,
                op: 'EQ'
              }
              rules.push(rule)
            }
          })
          const filters = {}
          if (rules.length > 0) {
            filters.rules = rules
            filters.groupOp = 'OR'
          }
          this.$refs.documentTable.setMultiSearchFilter(filters)
          this.getData()
        })
      }
    }
  },
  methods: {
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection)
      } else {
        this.$emit('listenToDocumentEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    getData() {
      if (this.$refs.documentTable !== undefined) {
        this.$refs.documentTable.getDataList()
      }
    },
    getStateOptionList() {
      return this.stateOptionList
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 将选中记录赋值给multipleSelection
      this.multipleSelection = val
    },
    openDetail(row) {
      this.documentId = row.id
      this.showDocument = true
    }
  }
}
</script>
